StoreConfig

Struct StoreConfig 

pub struct StoreConfig {
    pub query_channel_size: usize,
    pub query_parallelism: usize,
    pub handle_watch_query_channel_size: usize,
    pub chain_events_batch_size: usize,
    pub mutation_tracker_timeout: Duration,
    pub garbage_collect_interval: Duration,
    pub chain_index_deferred_interval: Option<Duration>,
    pub chain_index_deferred_query_interval: Duration,
    pub chain_index_deferred_max_interval: Duration,
}
Configuration for Store.

Fields

query_channel_size: usize

Size of the channel of queries to be executed.

query_parallelism: usize

Maximum number fo queries to execute in parallel.

handle_watch_query_channel_size: usize

Size of the result channel of each watched query.

chain_events_batch_size: usize

Maximum number of events from chain engine to batch together if more are available.

mutation_tracker_timeout: Duration

Timeout for mutations that were awaiting for entities to be returned.

garbage_collect_interval: Duration

How often the garbage collection process will run.

Since garbage collection doesn’t happen on the whole index, but only on entities that got flagged during search, it is better to run more often than less. GarbageCollectorConfig::queue_size can be tweaked to control rate of collection.

chain_index_deferred_interval: Option<Duration>

Specifies the interval at which new blocks in the chain get indexed. New blocks may not necessarily get immediately indexed if they don’t fall in the interval of chain_index_min_depth and chain_index_depth_leeway.

Indexation can also be prevented if user queries were recently executed (see chain_index_deferred_query_secs)

If ‘0’ is specified, deferred indexation is disabled and blocks are indexed when the chain layer emits events.

chain_index_deferred_query_interval: Duration

Specifies the minimum interval to wait before indexing chain blocks after receiving a user query. It prevents potential slow downs caused by chain indexation if a user query get executed frequently.

chain_index_deferred_max_interval: Duration

Specifies the maximum interval for which indexation may be blocked by incoming user queries.